#[repr(u8)]pub enum Sstop {
VALUE00 = 0,
VALUE01 = 1,
VALUE10 = 2,
VALUE11 = 3,
}Variants
VALUE00 = 0
Stop bit disabled for Transmitter, Receiver, and Match Store modes
VALUE01 = 1
Stop bit disabled for Transmitter, Receiver, and Match Store modes; when timer is in stop condition, Receiver and Match Store modes store receive data on the configured shift edge
VALUE10 = 2
Transmitter mode outputs stop bit value 0 in Match Store mode; if stop bit is not 0, Receiver and Match Store modes set error flag (when timer is in stop condition, these modes also store receive data on the configured shift edge)
VALUE11 = 3
Transmitter mode outputs stop bit value 1 in Match Store mode; if stop bit is not 1, Receiver and Match Store modes set error flag (when timer is in stop condition, these modes also store receive data on the configured shift edge)
Implementations