#[repr(u8)]pub enum Timrst {
NEVER = 0,
TMR_OUT_HI = 1,
PIN_EQ_TMR_OUT = 2,
TRIG_EQ_TMR_OUT = 3,
PIN_RISE_EDGE = 4,
_RESERVED_5 = 5,
TRIG_RISE_EDGE = 6,
TRIG_EDGE = 7,
}Variants
NEVER = 0
Never reset timer
TMR_OUT_HI = 1
Timer reset on timer output high.
PIN_EQ_TMR_OUT = 2
Timer reset on timer pin equal to timer output
TRIG_EQ_TMR_OUT = 3
Timer reset on timer trigger equal to timer output
PIN_RISE_EDGE = 4
Timer reset on timer pin rising edge
_RESERVED_5 = 5
TRIG_RISE_EDGE = 6
Timer reset on trigger rising edge
TRIG_EDGE = 7
Timer reset on trigger rising or falling edge
Implementations